package com.ruoyi.web.controller.back;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.entity.CategoryInfo;
import com.ruoyi.common.core.domain.entity.MusicInfo;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.config.AliConfig;
import com.ruoyi.system.service.ICategoryInfoService;
import com.ruoyi.system.service.IMusicInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.List;

/**
 * 【请填写功能名称】Controller
 * 
 * @author ruoyi
 * @date 2025-07-15
 */
@RestController
@RequestMapping("/back/category")
public class CategoryInfoController extends BaseController
{
    @Autowired
    private ICategoryInfoService categoryInfoService;
    @Autowired
    private IMusicInfoService musicInfoService;
    /**
     * 查询【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('system:info:list')")
    @GetMapping("/list")
    public TableDataInfo list(CategoryInfo categoryInfo)
    {
        startPage();
        List<CategoryInfo> list = categoryInfoService.selectCategoryInfoList(categoryInfo);
        return getDataTable(list);
    }


    // 根据分类获取分类音乐
    @GetMapping("/cate/music/{categoryId}")
    public TableDataInfo getCategoryMusic(@PathVariable String categoryId){
        startPage();
        List<MusicInfo> list = musicInfoService.selectMusicInfoByCid(categoryId);
        return getDataTable(list);
    }

    /**
     * 导出【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('system:info:export')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CategoryInfo categoryInfo)
    {
        List<CategoryInfo> list = categoryInfoService.selectCategoryInfoList(categoryInfo);
        ExcelUtil<CategoryInfo> util = new ExcelUtil<CategoryInfo>(CategoryInfo.class);
        util.exportExcel(response, list, "【请填写功能名称】数据");
    }

    /**
     * 获取【请填写功能名称】详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:info:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(categoryInfoService.selectCategoryInfoById(id));
    }

    /**
     * 新增【请填写功能名称】
     */
//    @PreAuthorize("@ss.hasPermi('system:info:add')")
//    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody  CategoryInfo categoryInfo) throws IOException {
//        String imgAddr = AliConfig.ossUp("config/", file.getOriginalFilename(), file.getInputStream());
//        CategoryInfo categoryInfo = new CategoryInfo();
//        categoryInfo.setBackImg(imgAddr);
//        categoryInfo.setName(name);
        return toAjax(categoryInfoService.insertCategoryInfo(categoryInfo));
    }

    /**
     * 修改【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:info:edit')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CategoryInfo categoryInfo)
    {
        return toAjax(categoryInfoService.updateCategoryInfo(categoryInfo));
    }

    /**
     * 删除【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:info:remove')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        return toAjax(categoryInfoService.deleteCategoryInfoByIds(ids));
    }

    @PutMapping("/bind/{categoryId}/{ids}")
    public AjaxResult bindMusic(@PathVariable String categoryId,@PathVariable String[] ids){
         int insertCount = categoryInfoService.bindMusic(categoryId,ids);
         if (insertCount > 0){
             return AjaxResult.success();
         }
        return AjaxResult.error();

    }


}
